@@ -7,6 +7,17 @@ from .enum import ChannelType, try_enum
 from .mixins import Hashable
 from .object import Object
 
+__all__ = (
+    'TextChannel',
+    'VoiceChannel',
+    'LiveChannel',
+    'AppChannel',
+    'CategoryChannel',
+    'ThreadChannel',
+    'PartialMessageable',
+)
+
+
 if TYPE_CHECKING:
     from .member import Member
     from .message import Message, PartialMessage
@@ -28,7 +39,6 @@ async def _single_delete_strategy(messages: Iterable[Message]):
 
 
 class TextChannel(abc.Messageable, abc.GuildChannel, Hashable):
-
     """代表 QQ 频道中的文字子频道
 
     .. container:: operations
