@@ -252,7 +252,7 @@ class HTTPClient:
                    rsp.status_code)
         return rsp.json()
 
-    def sync_get_bot_member(self,guild_id: int, user_id: int) -> MemberPayload:
+    def sync_get_bot_member(self, guild_id: int, user_id: int) -> MemberPayload:
         headers: Dict[str, str] = {
             'User-Agent': self.user_agent,
         }
@@ -264,7 +264,8 @@ class HTTPClient:
         if rsp.status_code == 200:
             return rsp.json()
 
-    def sync_guild_channels_roles(self, guild_id: int) -> Tuple[List[ChannelPayload], List[RolePayload], List[MemberPayload]]:
+    def sync_guild_channels_roles(self, guild_id: int) -> Tuple[
+        List[ChannelPayload], List[RolePayload], List[MemberPayload]]:
         headers: Dict[str, str] = {
             'User-Agent': self.user_agent,
         }
