@@ -15,8 +15,9 @@ from .mixins import Hashable
 from .role import Role
 from .utils import escape_mentions
 from .guild import Guild
-from .error import HTTPException
+from .partial_emoji import PartialEmoji
 from .embeds import Embed
+from .reaction import Reaction
 
 if TYPE_CHECKING:
     from .state import ConnectionState
@@ -24,13 +25,51 @@ if TYPE_CHECKING:
     from .channel import TextChannel
     from .enum import ChannelType
     from .types.message import Attachment as AttachmentPayload, Message as MessagePayload, \
-        MessageReference as MessageReferencePayload
+        MessageReference as MessageReferencePayload, Reaction as ReactionPayload
     from .types.embed import Embed as EmbedPayload
     from .types.user import User as UserPayload
     from .types.member import Member as MemberPayload, UserWithMember as UserWithMemberPayload
     from .user import User
 
     MR = TypeVar('MR', bound='MessageReference')
+EmojiInputType = Union[PartialEmoji, str]
+
+__all__ = (
+    'Attachment',
+    'Message',
+    'PartialMessage',
+    'MessageReference',
+)
+
+
+class DeletedReferencedMessage:
+    """一种特殊的标记类型，表示已解析的消息引用的消息是否已被删除。
+    此类的目的是将无法获取的引用消息与先前获取但已被删除的消息分开。
+    """
+
+    __slots__ = ('_parent',)
+
+    def __init__(self, parent: MessageReference):
+        self._parent: MessageReference = parent
+
+    def __repr__(self) -> str:
+        return f"<DeletedReferencedMessage id={self.id} channel_id={self.channel_id} guild_id={self.guild_id!r}>"
+
+    @property
+    def id(self) -> int:
+        """:class:`int`: 已删除的引用消息的消息 ID。"""
+        # the parent's message id won't be None here
+        return self._parent.message_id  # type: ignore
+
+    @property
+    def channel_id(self) -> int:
+        """:class:`int`: 已删除的引用消息的子频道 ID。"""
+        return self._parent.channel_id
+
+    @property
+    def guild_id(self) -> Optional[int]:
+        """Optional[:class:`int`]: 删除的引用消息的频道 ID。"""
+        return self._parent.guild_id
 
 
 class MessageReference:
@@ -154,9 +193,9 @@ class Attachment(Hashable):
         self.height: Optional[int] = data.get('height')
         self.width: Optional[int] = data.get('width')
         self.filename: str = data['filename']
-        self.url: str = 'https://' + data.get('url')\
-                        if not data.get('url').startswith('https://') \
-                        else data.get('url')
+        self.url: str = 'https://' + data.get('url') \
+            if not data.get('url').startswith('https://') \
+            else data.get('url')
         self._http = state.http
         self.content_type: Optional[str] = data.get('content_type')
 
@@ -359,7 +398,8 @@ class Message(Hashable):
         'guild',
         'reference',
         'role_mentions',
-        'created_at'
+        'created_at',
+        'reactions'
     )
 
     if TYPE_CHECKING:
@@ -380,6 +420,7 @@ class Message(Hashable):
         self._state: ConnectionState = state
         self.created_at = datetime.datetime.now()
         self.id: str = data['id']
+        self.reactions: List[Reaction] = [Reaction(message=self, data=d) for d in data.get('reactions', [])]
         self.attachments: Optional[List[Attachment]] = \
             [Attachment(data=a, state=self._state) for a in data['attachments']] \
                 if 'attachments' in data else None
@@ -398,6 +439,32 @@ class Message(Hashable):
         except AttributeError:
             self.guild = state._get_guild(data.get('guild_id'))
 
+        try:
+            ref = data['message_reference']
+        except KeyError:
+            self.reference = None
+        else:
+            self.reference = ref = MessageReference.with_state(state, ref)
+            try:
+                resolved = data['referenced_message']
+            except KeyError:
+                pass
+            else:
+                if resolved is None:
+                    ref.resolved = DeletedReferencedMessage(ref)
+                else:
+                    # Right now the channel IDs match but maybe in the future they won't.
+                    if ref.channel_id == channel.id:
+                        chan = channel
+                    else:
+                        chan, _ = state._get_guild_channel(resolved)
+
+                    # the channel will be the correct type here
+                    ref.resolved = self.__class__(channel=chan, data=resolved, state=state)  # type: ignore
+
+        if 'mentions' not in data:
+            data['mentions'] = []
+
         for handler in ('author', 'member', 'mentions'):
             try:
                 getattr(self, f'_handle_{handler}')(data[handler])
@@ -497,6 +564,39 @@ class Message(Hashable):
         self.guild = new_guild
         self.channel = new_channel
 
+    def _add_reaction(self, data, emoji, user_id) -> Reaction:
+        reaction = utils.find(lambda r: r.emoji == emoji, self.reactions)
+        is_me = data['me'] = user_id == self._state.self_id
+
+        if reaction is None:
+            reaction = Reaction(message=self, data=data, emoji=emoji)
+            self.reactions.append(reaction)
+        else:
+            reaction.count += 1
+            if is_me:
+                reaction.me = is_me
+
+        return reaction
+
+    def _remove_reaction(self, data: ReactionPayload, emoji: EmojiInputType, user_id: int) -> Reaction:
+        reaction = utils.find(lambda r: r.emoji == emoji, self.reactions)
+
+        if reaction is None:
+            # already removed?
+            raise ValueError('Emoji already removed?')
+
+        # if reaction isn't in the list, we crash. This means discord
+        # sent bad data, or we stored improperly
+        reaction.count -= 1
+
+        if user_id == self._state.self_id:
+            reaction.me = False
+        if reaction.count == 0:
+            # this raises ValueError if something went wrong as well.
+            self.reactions.remove(reaction)
+
+        return reaction
+
     @utils.cached_slot_property('_cs_raw_mentions')
     def raw_mentions(self) -> List[int]:
         """List[:class:`int`]: 返回与消息内容中的 ``<@user_id>`` 语法匹配的用户 ID 数组的属性。
@@ -563,12 +663,12 @@ class Message(Hashable):
         transformations.update(mention_transforms)
         transformations.update(second_mention_transforms)
 
-        if self.guild is not None:
-            role_transforms = {
-                re.escape(f'<@&{role.id}>'): '@' + role.name
-                for role in self.role_mentions
-            }
-            transformations.update(role_transforms)
+        # if self.guild is not None:
+        #     role_transforms = {
+        #         re.escape(f'<@&{role.id}>'): '@' + role.name
+        #         for role in self.role_mentions
+        #     }
+        #     transformations.update(role_transforms)
 
         # fmt: on
 
@@ -581,9 +681,28 @@ class Message(Hashable):
 
     @property
     def edited_at(self) -> Optional[datetime.datetime]:
+        """Optional[:class:`datetime.datetime`]: 包含消息编辑时间的 aware UTC datetime 对象。"""
         return self._edited_timestamp
 
     async def reply(self, content: Optional[str] = None, **kwargs) -> Message:
+        """|coro|
+        :meth:`.abc.Messageable.send` 回复 :class:`.Message` 的快捷方法。
+
+
+        Raises
+        --------
+        ~qq.HTTPException
+            发送消息失败。
+        ~qq.Forbidden
+            您没有发送消息的适当权限。
+        ~qq.InvalidArgument
+            ``files`` 列表的大小不合适，或者您同时指定了 ``file`` 和 ``files``。
+
+        Returns
+        ---------
+        :class:`.Message`
+            发送的消息。
+        """
         return await self.channel.send(content, reference=self, **kwargs)
 
     def to_reference(self, *, fail_if_not_exists: bool = True) -> MessageReference:
